Integracja API
Udost瘼niamy naszym u篡tkownikom interfejs API, dzi瘯i kt鏎emu mo積a w zautomatyzowany spos鏏 doda� wi瘯sz� ilo嗆 og這sze� do serwisu lub dokonywa� eksportu og這sze� z serwisu partnerskiego.

  1. Jak rozpocz帷 korzystanie z API?
  2. Przesy豉nie zapyta�
  3. Zwracane odpowiedzi
  4. Autoryzacja
  5. Jak doda� og這szenie za pomoc� API?
  6. Pobieranie listy kategorii
  7. Pobieranie listy miast
  8. Jak doda� og這szenie Premium lub Wyr騜nione?
  9. Jak doda� zdj璚ia do og這szenia
  10. Wy鈍ietlenie listy zdj耩 dodanych do og這szenia
  11. Wy鈍ietlenie zdj璚ia dodanego do og這szenia
  12. Usuni璚ie pojedy鎍zego zdj璚ia
  13. Usuni璚ie wszystkich zdj耩 z og這szenia
  14. Edycja og這szenia
  15. Usuni璚ie og這szenia
  16. Sprawdzenie limitu konta
  17. Jak zwi瘯szy� limit dla konta??
Jak rozpocz帷 korzystanie z API?
Aby rozpocz望 korzystanie z API nale篡 wygenerowa� klucz API.

Klucz API jest unikalny dla ka盥ego u篡tkownika i powinien by� traktowany jak has這 do konta.

W celu wygenerowania klucza API przejd� na t� stron�.
Przesy豉nie zapyta�
API zosta這 napisane wed逝g standardu REST i dost瘼ne jest pod adresem https://api.oglaszamy24.pl/api/

Zar闚no zapytania, jak i odpowiedzi przesy豉ne s� za pomoc� protoko逝 HTTPS.

API obs逝guje 4 dost瘼ne metody zapyta�: POST, GET, PUT, DELETE.

W przypadku zapyta� POST oraz PUT nale篡 przes豉� odpowiednie dane jako parametr "data". Przesy豉ne dane musz� by� w formacie JSON a znaki musz� by� zakodowane w standardzie UTF-8.
Zwracane odpowiedzi
Po przes豉niu zapytania API zwr鏂i odpowied� w formacie JSON. Znaki zakodowane b璠� w formacie UTF-8.

W przypadku poprawnej odpowiedzi zwr鏂ona odpowied� zawiera� b璠zie pola:
  • status - pole przyjmie warto嗆 "ok"
oraz opcjonalnie nast瘼uj帷e pola:
  • message - komunikat przes豉ny jako odpowied�
  • data - dane przes豉ne w odpowiedzi
Przyk豉dowa poprawna odpowied�:

{"status":"ok", "message":"hello", "data":{"method":"GET"}}


W przypadku b喚dnej odpowiedzi zwr鏂ona odpowied� zawiera� b璠zie pola:
  • status - pole przyjmie warto嗆 "error"
  • message - w polu znajdzie si� komunikat z b喚dem
  • code - kod b喚du
Przyk豉dowa b喚dna odpowied�:

{"status":"error", "message":"Niepoprawna komenda API.", "code":9}
Autoryzacja
Do ka盥ego zapytania nale篡 przes豉� klucz API.

Klucz API musi zosta� przes豉ny w nag堯wku header zapytania jako parametr API-Key.

Przyk豉dowe przes豉nie klucza API za pomoc� biblioteki CURL.

curl -X GET -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/hello

Przyk豉dowe przes豉nie klucza API za pomoc� PHP:

$api_key = 'TWOJ-KLUCZ-API';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/hello');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);

W odpowiedzi serwer powinien zwr鏂i� nast瘼uj帷� odpowied�:

{"status":"ok", "message":"hello", "data":{"method":"GET"}}
Jak doda� og這szenie za pomoc� API?
W celu dodania og這szenia za pomoc� API nale篡 wys豉� dane og這szenia zakodowane w formacie JSON (kodowanie znak闚 w UTF-8).

Dane musz� zosta� przes豉ne za pomoc� metody POST jako parametr "data" na adres:

https://api.oglaszamy24.pl/api/adverts

Dane mog� zawiera� nast瘼uj帷e pola:

Parametr
Obowi您kowy
Typ
Opis
title
obowi您kowy
string
Tytu� og這szenia. Minimalna d逝go嗆 to 5 znak闚.
description
obowi您kowy
string
Tre嗆 og這szenia. Maksymalna d逝go嗆 to 4000 znak闚. Nowe linie w opisie nale篡 oddziela� za pomoc� znacznika: \r\n
cat1_id
obowi您kowy
integer
cat2_id
obowi您kowy
integer
ID podkategorii drugiego rz璠u. Je瞠li podkategoria drugiego rz璠u zawiera podkategorie trzeciego rz璠u, nale篡 w闚czas okre郵i� ID kategorii trzeciego rz璠u (cat3_id).
cat3_id
obowi您kowy
integer
ID podkategorii trzeciego rz璠u. W przypadku gdy dana podkategoria drugiego rz璠u nie posiada dalszych podkategorii warto嗆 nale篡 ustawi� jako 0.
contact_name
obowi您kowy
string
Imie osoby kontaktowej
telephone
nieobowi您kowy
integer
Numer telefonu kontaktowego. Bez spacji. W przypadku kierunkowego wpisa� 00 zamiast +.
email_disabled
nieobowi您kowy
integer
Dost瘼ne warto軼i: 0 lub 1. W przypadku gdy nie chcemy otrzymywa� odpowiedzi mailem a jedynie telefonicznie nale篡 ustawi� warto嗆 parametru jako 1.
ad_sell
nieobowi您kowy
integer
Liczba ca趾owita okre郵aj帷a rodzaj oferty. Dost瘼ne warto軼i: 1 lub 2. Je瞠li oferta dotyczy sprzeda篡/wynajmu komu�/oferowania us逝g ustaw warto嗆 parametru jako 1, je瞠li oferta dotyczy kupna/wynajmu od kogo�/poszukiwania us逝g ustaw warto嗆 parametru jako 2. W przypadku pomini璚ia parametru, przyjmie on domy郵n� warto嗆 1.
price
nieobowi您kowy
integer
Cena w z�. Dotyczy przedmiot闚 wystawionych na sprzeda� lub oferowanch us逝g.
city_id
nieobowi您kowy
integer
ID miasta do kt鏎ego chcemy doda� og這szenie (zobacz poni瞠j pobieranie listy miast). Je瞠li chcemy aby og這szenie wy鈍ietla這 si� we wszystkich miastach, nale篡 poda� warto嗆 0.
ad_type
nieobowi您kowy
integer
rodzaj og這szenia (dost瘼ne warto軼i: 1,2 lub 3). 1 - og這szenie standardowe, 2 - og這szenie premium, 3 - og這szenie wyr騜nione. W przypadku dodawania og這szenia premium lub wyr騜nionego nale篡 uprzednio zakupi� pakiet og這sze� Wyr騜nionych lub Premium.
auto_renewal
nieobowi您kowy
integer
Dost瘼ne warto軼i: 1 lub 0. Je瞠li chcemy aby og這szenie Premium lub Wyr騜nionych by這 automatycznie ponawiane w闚czas ustaw warto嗆 parametru jako 1. Aby og這szenie mog這 by� automatycznie ponowione nale篡, w momencie ponawiania, posiada� aktywny pakiet og這sze� Wyr騜nionych lub Premium.
extra_info
nieobowi您kowy
array
Dodatkowe informacje dost瘼ne w przypadku niekt鏎ych kategorii takich jak nieruchomo軼i czy motoryzacja (zobacz poni瞠j)


Uwagi:
W przypadku ustawienia warto軼i parametru email_disabled jako 1 parametr telephone b璠zie obowi您kowy.

Domy郵nie og這szenia b璠� dodawane z adresem email kontaktowym podanym podczas rejestracji konta. Je瞠li exportujesz og這szenia z serwisu partnerskiego lub chcia豚y� dodawa� og這szenia z r騜nymi adresami email - skontaktuj si� z nami.



Parametr extra_info:

Parametr extra_info to tablica sk豉daj帷a si� z p鏊 info1...info12. W parametrze extra_info, w polach info1...info12, mo積a poda� dodatkowe informacje o sprzedawanej/wynajmowanej nieruchomo軼i, samochodzie lub motocyklu.

Parametry info1...info12 nie s� obowi您kowe.


W przypadku wynajmu nieruchomo軼i:

Parametr
Typ
Opis
info1
integer
Liczba pokoi. 0 - nie okre郵ono
info2
integer
Liczba 豉zienek. 0 - nie okre郵ono
info3
integer
Na kt鏎ym pi皻rze znajduje si� mieszkanie (np. 1, 2, 3) . 0 - Parter, -1 - Nie okre郵ono
info4
integer
Czy jest pod陰czony internet.

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Brak
2 - Jest
3 - Mo積a pod陰czy�
info5
integer
Okre郵a czy nieruchomo嗆 mog� wynaj望 osoby pal帷e.

Dost瘼ne warto軼i:
0 - Oboj皻nie
1 - Tak
2 - Nie
info6
integer
Dla ilu os鏏 ma by� wynaj皻a nieruchomo嗆.
info7
integer
Metra� mieszkania (warto嗆 w m2.)
info8
integer
Kaucja w z�.
info9
integer
Dodatkowe op豉ty takie jak np. pr康, gaz. Kwota w z�.
info10
string
Dzielnica w kt鏎ej znajduje si� nieruchomo嗆.
info11
string
Ulica przy kt鏎ej po這穎na jest nieruchomo嗆.
info12
string
Od kiedy dost瘼ne do wynaj璚ia. Data w formacie YYYY-MM-DD (rok-miesiac-dzie�)


W przypadku sprzeda篡 nieruchomo軼i - domu:

Parametr
Typ
Opis
info1
integer
Liczba pokoi. 0 - nie okre郵ono
info2
integer
Liczba 豉zienek. 0 - nie okre郵ono
info3
integer
Rodzaj ogrzewania

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Miejskie
2 - Gazowe
3 - Elektryczne
4 - W璕lowe
5 - Olejowe
6 - Inne
info4
integer
Typ budynku:

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Wolnostoj帷y
2 - Bli幡iak
3 - Kamienica
4 - Willa
5 - Szeregowy
6 - Inny
info5
integer
Liczba pi皻er. 0 - nie okre郵ono, 1 - dom parterowy
info6
integer
Materia� jaki zastosowano do budowy.

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Ceg豉
2 - Pustak
3 - P造ta
4 - Gazobeton
5 - Bloczki
6 - Drewno
7 - Inny
info7
integer
Metra� (warto嗆 w m2.)
info8
integer
Rok budowy (YYYY, np. 1995)
info10
string
Dzielnica w kt鏎ej znajduje si� nieruchomo嗆.
info11
string
Ulica przy kt鏎ej po這穎na jest nieruchomo嗆.


W przypadku sprzeda篡 nieruchomo軼i - mieszkania:

Parametr
Typ
Opis
info1
integer
Liczba pokoi. 0 - nie okre郵ono
info2
integer
Liczba 豉zienek. 0 - nie okre郵ono
info3
integer
Rodzaj ogrzewania

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Miejskie
2 - Gazowe
3 - Elektryczne
4 - W璕lowe
5 - Olejowe
6 - Inne
info4
integer
Na kt鏎ym pi皻rze znajduje si� mieszkanie (np. 1, 2, 3) . 0 - Parter, -1 - Nie okre郵ono
info5
integer
Okre郵a materia� jaki zastosowano do budowy.

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Ceg豉
2 - Pustak
3 - P造ta
4 - Gazobeton
5 - Bloczki
6 - Drewno
7 - Inny
info7
integer
Metra� mieszkania (warto嗆 w m2.)
info10
string
Dzielnica w kt鏎ej znajduje si� nieruchomo嗆.
info11
string
Ulica przy kt鏎ej po這穎na jest nieruchomo嗆.


W przypadku samochodu:

Parametr
Typ
Opis
info1
integer
Typ pojazdu

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Sedan/Limuzyna
2 - Hatchback
3 - Kombi
4 - Van
5 - Kabriolet
6 - Suv/Terenowy
7 - Pick-up
8 - Inny
info2
integer
Typ silnika

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Benzyna
2 - Benzyna+Gaz
3 - Diesel
4 - Hybryda
5 - Elektryczny
6 - CNG
7 - Inny
info3
integer
Liczba drzwi

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - 2/3
2 - 4/5
3 - 6/7
info4
integer
Skrzynia bieg闚

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Manualna
2 - Automatyczna
3 - P馧automatyczna
info5
integer
Okre郵a czy pojazd uszkodzony. Warto軼i: 1 - nie, 2 - tak, 0 - nie okre郵ono
info6
integer
Klimatyzacja. Warto軼i: 1 - jest, 2 - brak, 0 - nie okre郵ono
info7
integer
Rok produkcji samochodu (YYYY, np. 2014). 0 - Nie okre郵ono
info8
integer
Pojemno嗆 silnika

Przyk豉dowe warto軼i:
Warto嗆 parametru: 90 - oznacza 0,9 litra
Warto嗆 parametru: 100 - oznacza 1,0 litra
Warto嗆 parametru: 110 - oznacza 1,1 litra
Warto嗆 parametru: 120 - oznacza 1,2 litra
info9
integer
Dotychczasowy przebieg w km


W przypadku motocykla:

Parametr
Typ
Opis
info1
integer
Okre郵a czy motocykl jest uszkodzony. Warto軼i: 0 - nie okre郵ono, 1 - nie , 2 - tak
info2
integer
Typ silnika

Dost瘼ne warto軼i:
0 - Nie okre郵ono
1 - Benzyna
2 - Benzyna+Gaz
3 - Diesel
4 - Hybryda
5 - Elektryczny
6 - CNG
7 - Inny
info7
integer
Rok produkcji (format YYYY, np. 1995). 0 - Nie okre郵ono.
info8
integer
Pojemno嗆 silnika w cm3

Przyk豉dowe warto軼i:
Warto嗆 parametru: 90 - oznacza 90 cm3
Warto嗆 parametru: 100 - oznacza 100 cm3
Warto嗆 parametru: 110 - oznacza 110 cm3
Warto嗆 parametru: 120 - oznacza 120 cm3
info9
integer
Dotychczasowy przebieg w km.
info10
string
Okre郵a wersji konkretnego modelu.
Parametr images:

W parametrze images nale篡 poda� list� adres闚 URL ze zdj璚iami w formacie JPG. Zdj璚ia musz� by� dost瘼ne pod wskazanymi adresami URL tak aby nasze interfejs API m鏬� je pobra�. Maksymalny rozmiar pojedy鎍zego zdj璚ia to 2 MB.

Przyk豉dowa warto嗆 parametru images zawieraj帷a 2 zdj璚ia (JSON):

{"images":["adres_url_do_zdjecia_1.jpg", "adres_url_do_zdjecia_1.jpg"]}


Podaj帷 adres do zdj璚ia nale篡 poda� pe軟y adres URL rozpoczynaj帷y sie od http lub https.

Przyk豉dowo: http://www.mojadomena.pl/zdjecia/zdjecie1.jpg

Do og這sze� standardowych mo積a doda� maksymalnie 2 zdj璚ia. Natomiast do og這szen Premium lub Wyr騜nionych mo積a doda� maksymalnie 10 zdj耩.



Przyk豉d w j瞛yku PHP pokazuj帷y dodanie og這szenia:

$data = array();
$data['title'] = 'Du瞠 mieszkanie do wynaj璚ia';
$data['description'] = "Do wynaj璚ia dla 2 os鏏, dwupokojowe mieszkanie w Krakowie.\r\n";
$data['description'] .= 'Mieszkanie jest ca趾owicie umeblowane niedawno wyremontowane.';
$data['price'] = 2100; // cena w z�

$data['cat1_id'] = 2; // nieruchomo軼i
$data['cat2_id'] = 24; // wynajem
$data['cat3_id'] = 97; // mieszkania

$data['ad_sell'] = 1;
$data['city_id'] = 2; // Krak闚

$data['telephone'] = 5012012013;
$data['contact_name'] = 'Jan Kowalski';

$data['ad_type'] = 1; // og這szenie standardowe
$data['auto_renewal'] = 0;
$data['extra_info'] = array();
$data['extra_info']['info1'] = 2; // dwupokojowe
$data['extra_info']['info2'] = 1; // jedna 豉zienka
$data['extra_info']['info3'] = 4; // pi皻ro
$data['extra_info']['info4'] = 2; // internet
$data['extra_info']['info5'] = 0; // dla pal帷ych
$data['extra_info']['info6'] = 2; // dla 2 osob
$data['extra_info']['info7'] = 52; // metra� - 52m kw
$data['extra_info']['info8'] = 1200; // kaucja w z�
$data['extra_info']['info9'] = 1000; // dodatowe oplaty w z�
$data['extra_info']['info10'] = 'Stare miasto'; // dzielnica
$data['extra_info']['info11'] = 'Garncarska'; // ulica
$data['extra_info']['info12'] = '2019-03-21'; // wolne od

$data = json_encode($data);

$api_key = 'TWOJ-KLUCZ-API'; // wpisz tutaj sw鎩 klucz API
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query(array('data' => $data)));
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);
$response = json_decode($response);

if ($response->status == 'ok') echo 'ID dodanego og這szenia to: '.$response->data->id;
else if ($response->status == 'error') echo 'Wyst徙i� problem podczas dodawania og這szenia: '.$response->message;


W przypadku prawid這wego dodania og這szenia otrzymamy odpowied� w formacie JSON, gdzie pole status zawiera� b璠zie ok. Dodatkowo w odpowiedzi zostanie przes豉ne ID og這szenia, kt鏎e zosta這 dodane.

ID to nale篡 zachowa� poniewa� b璠zie ono potrzebne gdyby鄉y chcieli zmodyfikowa� og這szenie lub je usun望.

Przyk豉dowa odpowied� po poprawnym dodaniu og這szenia (ID nowego og這szenia to 123456):

{"status":"ok", "message":"Og這szenie zosta這 dodane", "data":{"id":"123456"}}

W przypadku b喚du pole status zawiera� b璠zie warto嗆 error a w polu message podany b璠zie komunikat o b喚dzie.

Przyk豉d pokazuj帷y dodanie tego samego og這szenia przy wykorzystaniu biblioteki CURL:

curl -H 'API-Key: TWOJ-KLUCZ-API' --data 'data={"title":"Du\u017ce mieszkanie do wynaj\u0119cia","description":"Do wynaj\u0119cia dla 2 os\u00f3b, dwupokojowe mieszkanie w Krakowie.\r\nMieszkanie jest ca\u0142kowicie umeblowane niedawno wyremontowane.", "price":2100, "cat1_id":2, "cat2_id":24, "cat3_id":97, "ad_sell":1, "city_id":2, "telephone":5012012013, "contact_name":"Jan Kowalski", "ad_type":1, "auto_renewal":0, "extra_info":{"info1":2, "info2":1,"info3":4, "info4":2,"info5":0, "info6":2, "info7":52, "info8":1200, "info9":1000, "info10":"Stare miasto", "info11":"Garncarska", "info12":"2019-03-21"}}' https://api.oglaszamy24.pl/api/adverts

Pobieranie listy kategorii
W celu pobrania listy kategorii nale篡 wys豉� zapytanie GET pod adres:

https://api.oglaszamy24.pl/api/categories


W odpowiedzi otrzymamy list� dost瘼nych kategorii oraz podkategorii wraz z parametrami cat1_id, cat2_id, cat3_id.

Przyk豉d z u篡ciem biblioteki CURL.

curl -X GET -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/categories
Pobieranie listy miast
W celu pobrania listy kategorii nale篡 wys豉� zapytanie GET pod adres:

https://api.oglaszamy24.pl/api/cities

W odpowiedzi otrzymamy list� dost瘼nych miast do kt鏎ych mo積a doda� og這szenia wraz z ID miasta (parametr city_id).

Przyk豉d z u篡ciem biblioteki CURL:

curl -X GET -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/cities


Standardowo wszystkie og這szenia dodawane za pomoc� API zamieszczane s� na okres 2 tygodni. Wcze郾iejsze usuni璚ie og這szenia mo磧iwe jest za pomoc� odpowiedniej komendy API.
Jak doda� og這szenie Premium lub Wyr騜nione?
W celu dodania og這szenia Premium lub Wyr騜nionego za pomoc� API nale篡 uprzednio posiada� odpowiedni pakiet og這sze� a nast瘼nie dodaj帷 og這szenie z u篡ciem API w paramerze ad_type nale篡 przes豉� warto嗆: 2 - je瞠li chcemy doda� og這szenie Wyr騜nione - lub 3 je瞠li chcemy doda� og這szenie Premium.
Jak doda� zdj璚ia do og這szenia?
Istniej� dwie metody dodania zdj耩 do og這szenia.
  • Pierwsza metoda polega na przes豉niu listy adres闚 URL, pod kt鏎ymi dost瘼ne s� zdj璚ia.
  • Druga metoda polega na bezpo鈔ednim przes豉niu plik闚 ze zdj璚iami na adres serwera API.
W obydwu metodach zdj璚ia powinny by� w formacie JPG, a maksymalny rozmiar pojedy鎍zego zdj璚ia to 2 MB.


1. Metoda pierwsza - przes豉nie listy zdj耩.

W celu dodania zdj耩 do og這szenia nale篡 przes豉� zapytanie metod� POST pod adres URL:

https://api.oglaszamy24.pl/api/adverts/{id_ogloszenia}/images


gdzie {id_ogloszenia} to ID og這szenia do kt鏎ego chcemy doda� zdj璚ia.

Zapytanie musi zawiera� parametr POST "data" z danymi zakodowanymi w formacie JSON.

W parametrze POST data nale篡 przes豉� zmienn� images zawieraj帷� list� adres闚 URL ze zdj璚iami w formacie JPG. Zdj璚ia musz� by� dost瘼ne pod wskazanymi adresami URL tak aby nasze interfejs API m鏬� je pobra�. Maksymalny rozmiar pojedy鎍zego zdj璚ia to 2 MB.

Przyk豉dowa warto嗆 parametru images zawieraj帷a 2 zdj璚ia:

{"images":["adres_url_do_zdjecia1.jpg", "adres_url_do_zdjecia2.jpg"]}

Podaj帷 adres do zdj璚ia nale篡 poda� pe軟y adres URL rozpoczynaj帷y sie od http lub https.

Przyk豉dowo: http://www.mojadomena.pl/zdjecia/zdjecie1.jpg

Do og這sze� bezp豉tnych mo積a doda� maksymalnie 2 zdj璚ia. Natomiast do og這szen Premium lub Wyr騜nionych mo積a doda� maksymalnie 10 zdj耩.

Przyk豉d dla j瞛yka PHP:

$api_key = 'TWOJ-KLUCZ-API';
$id = 12345;// ID ogloszenia
$data['images'] = array( 'http://www.mojadomena.pl/zdjecie1.jpg', 'http://www.mojadomena.pl/zdjecie2.jpg' );
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts/'. $id. '/images');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query(array('data' => json_encode($data))));
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);



2. Druga metoda - przes豉nie plik闚 ze zdj璚iami.

W celu dodania zdj耩 do og這szenia nale篡 przes豉� zapytanie metod� POST pod adres URL:

https://api.oglaszamy24.pl/api/adverts/{id_ogloszenia}/images/upload

gdzie {id_ogloszenia} to ID og這szenia do kt鏎ego chcemy doda� zdj璚ia.

W parametrze POST data nale篡 przes豉� plik ze zdj璚iem w formacje JPG.

Przyk豉d z wykorzystaniem biblioteki CURL:

curl -H 'API-Key: TWOJ-KLUCZ-API' -F 'data=@/home/images/zdjecie1.jpg' https://api.oglaszamy24.pl/api/adverts/12345/images/upload


Aby doda� kilka zdj耩 do og這szenia nale篡 wys豉� osobne zapytania dla ka盥ego zdj璚ia.

W przypadku porawnego dodania zdj璚ia w odpowiedzi pole status zawiera� b璠zie warto嗆 ok. Natomiast w przypadku b喚du pole status przyjmie warto嗆 error a w polu message zawarta b璠zie wiadomo嗆 z b喚dem.

Przyk豉dowa poprawna odpowied�:
{"status":"ok", "message":"Zdj璚ie zosta這 dodane."}
Wy鈍ietlenie listy zdj耩 dodanych do og這szenia
W celu otrzymania listy zdj耩, kt鏎e zosta造 dodane do og這szenia, nale篡 wys豉� zapytanie metod� GET pod adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}/images


W odpowiedzi otrzymamy list� ID zdj耩.

Przyk豉dowe zapytanie by otrzyma� list� zdj耩 dodanych do og這szenia o ID 12345 z u篡ciem biblioteki CURL:

curl -X GET -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/adverts/12345/images


Powy窺zy przyk豉d dla j瞛yka PHP:

$api_key = 'TWOJ-KLUCZ-API';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts/12345/images');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);
Wy鈍ietlenie zdj璚ia dodanego do og這szenia
W celu wy鈍ietlenia konkretnego zdj璚ia nale篡 wys豉� zapytanie metod� GET pod adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}/images/{id_zdj璚ia}

W odpowiedzi wy鈍ietlone zostanie zdj璚ie w formacie JPG.
Usuni璚ie pojedy鎍zego zdj璚ia
W celu usuni璚ia pojedy鎍zego zdj璚ia, nale篡 wys豉� zapytanie metod� DELETE pod adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}/images/{id_zdjecia}

Przyk豉dowe usuni璚ie zdj璚ia o ID 789 z og這szenia o ID 12345 przy u篡ciu biblioteki CURL.

curl -X DELETE -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/adverts/12345/images/789

Powy窺zy przyk豉d dla j瞛yka PHP:

$api_key = 'TWOJ-KLUCZ-API';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts/12345/images/789');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);

W odpowiedzi poprawnego usuni璚ia zdj璚ia w odpowiedzi serwer powinien zwr鏂i� nast瘼uj帷� odpowied�:

{"status":"ok","message":" Zdj璚ie zosta這 usuni皻e."}

W przypadku b喚du zostanie zwr鏂ona odpowied� z komunikatem o b喚dzie.
Usuni璚ie wszystkich zdj耩 z og這szenia
W celu usuni璚ia wszystkich zdj耩 z og這szenia, nale篡 wys豉� zapytanie metod� DELETE pod adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}/images

Przyk豉dowe usuni璚ie wszystkich zdj耩 z og這szenia o ID 12345 przy u篡ciu biblioteki CURL.

curl -X DELETE -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/adverts/12345/images

Powy窺zy przyk豉d dla j瞛yka PHP:

$api_key = 'TWOJ-KLUCZ-API';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts/12345/images');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);

W odpowiedzi poprawnego usuni璚ia zdj璚ia w odpowiedzi serwer powinien zwr鏂i� nast瘼uj帷� odpowied�:

{"status":"ok","message":" Zdj璚ia zosta造 usuni皻e."}

W przypadku b喚du zostanie zwr鏂ona odpowied� z komunikatem o b喚dzie.
Edycja og這szenia
W celu edycji og這szenia za pomoc� API nale篡 wys豉� dane og這szenia zakodowane w formacie JSON (kodowanie znak闚 w UTF-8).

Dane musz� zosta� przes豉ne za pomoc� metody PUT jako parametr "data" na adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}

Gdzie {id_og這szenia} to ID og這szenia, kt鏎e chcemy zmodyfikowa�.

Dane og這szenia przesy豉ne jako parametr data s� takie same jak w przypadku dodawania og這szenia.

Je瞠li chcesz zaktualizowa� zdj璚ia do og這szenia, nale篡 usun望 uprzednio dodane zdj璚ia za pomoc� odpowiedniej komendy API.
Usuni璚ie og這szenia
W celu usuni璚ia og這szenia, nale篡 wys豉� zapytanie metod� DELETE pod adres:

https://api.oglaszamy24.pl/api/adverts/{id_og這szenia}

Przyk豉dowe usuni璚ie og這szenia o ID 12345 przy u篡ciu biblioteki CURL.

curl -X DELETE -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/adverts/12345

Powy窺zy przyk豉d dla j瞛yka PHP:

$api_key = 'TWOJ-KLUCZ-API';
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, 'https://api.oglaszamy24.pl/api/adverts/12345');
curl_setopt($ch, CURLOPT_HTTPHEADER, array('API-Key: '.$api_key));
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
$response = curl_exec($ch);
curl_close ($ch);

W odpowiedzi , w przypadku poprawnego wykonania zapytania serwer powinien zwr鏂i� nast瘼uj帷� odpowied�:

{"status":"ok", "message":"Og這szenie zosta這 usuni皻e."}

W przypadku b喚du zostanie zwr鏂ona odpowied� z komunikatem o b喚dzie.
Sprawdzenie limitu konta
W celu sprawdzenia ile jeszcze og這sze� mo瞠my doda� poprzez API, nale篡 wys豉� zapytanie metod� GET pod adres:

https://api.oglaszamy24.pl/api/account

Przyk豉dowe zapytanie przy u篡ciu biblioteki CURL.

curl -X GET -H 'API-Key: TWOJ-KLUCZ-API' https://api.oglaszamy24.pl/api/account

W odpowiedzi, w przypadku poprawnego wykonania, serwer zwr鏂i odpowied� w formacje JSON, gdzie zmienna balance_standard, zawiera� b璠zie ilo嗆 standardowych og這sze�, kt鏎e mo瞠my jeszcze doda� bez do豉dowywania konta. Ponadto odpowied� zawiera� b璠zie pola balance_bold - ilo嗆 og這sze� wyr騜nionych, kt鏎e mo瞠my doda� oraz balance_premium - ilo嗆 og這sze� premium, kt鏎e mo瞠my doda�.

Przyk豉dowa odpowied�:

{"balance_standard":"175", "balance_bold":"0", "balance_premium":"15"}

Co oznacza, i� nasze saldo na koncie pozwala na dodanie jeszcze 175 og這sze�, a po przekroczeniu tego limitu konieczne b璠zie jego zwi瘯szenie.
Jak zwi瘯szy� limit API dla konta?
W celu zwi瘯szenia limitu API przejd� na stron� swojego konta.


Je瞠li masz dodatkowe pytania lub chcesz podzieli� si� uwagami - skontaktuj si� z nami.


© 2026 Oglaszamy24.pl | API | Wersja pe軟a
Zielona-gora.Oglaszamy24.pl - Darmowe og這szenia Zielona G鏎a. Dodaj bezp豉tne og這szenia drobne!